==> haskell-concurrent-output-1.7.9-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-concurrent-output.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: concurrent-output
version: 1.7.9
id: concurrent-output-1.7.9-9SnwuY3S39rFGSiA3rz5t1
key: concurrent-output-1.7.9-9SnwuY3S39rFGSiA3rz5t1
license: BSD2
copyright: 2015 Joey Hess, 2009 Joachim Breitner
maintainer: Joey Hess <id@joeyh.name>
stability: Stable
synopsis: Ungarble output from several threads or commands
description:
    Lets multiple threads and external processes concurrently output to the
    console, without it getting all garbled up.
    .
    Built on top of that is a way of defining multiple output regions,
    which are automatically laid out on the screen and can be individually
    updated by concurrent threads. Can be used for progress displays etc.
    .
    <<https://joeyh.name/code/concurrent-output/demo2.gif>>
category: User Interfaces
author: Joey Hess, Joachim Breitner
exposed: True
exposed-modules:
    System.Console.Concurrent System.Console.Concurrent.Internal
    System.Console.Regions System.Process.Concurrent
hidden-modules: Utility.Monad Utility.Data Utility.Exception
abi: 9753c395e8834c9f4515d45714da7e97
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/concurrent-output-1.7.9
library-dirs: /usr/lib/ghc-8.0.1/site-local/concurrent-output-1.7.9
data-dir: /usr/share/i386-linux-ghc-8.0.1/concurrent-output-1.7.9
hs-libraries: HSconcurrent-output-1.7.9-9SnwuY3S39rFGSiA3rz5t1
depends:
    ansi-terminal-0.6.2.3-AKTYR0nthhUCHW4HMZvJFX
    async-2.1.1-9CmNvQft9hOA1w6AR7WdJM base-4.9.0.0 directory-1.2.6.2
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN process-1.4.2.0
    stm-2.4.4.1-9HlGYelGmT69YkepeDjuRg
    terminal-size-0.3.2.1-LpkVHWZKZXdLX20uKh4q0i
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    unix-2.7.2.0
haddock-interfaces: /usr/share/doc/haskell-concurrent-output/html/concurrent-output.haddock
haddock-html: /usr/share/doc/haskell-concurrent-output/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-concurrent-output-1.7.9-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-concurrent-output.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: concurrent-output
version: 1.7.9
id: concurrent-output-1.7.9-GNR3nVD7tnXCDV8G96TgZE
key: concurrent-output-1.7.9-GNR3nVD7tnXCDV8G96TgZE
license: BSD2
copyright: 2015 Joey Hess, 2009 Joachim Breitner
maintainer: Joey Hess <id@joeyh.name>
stability: Stable
synopsis: Ungarble output from several threads or commands
description:
    Lets multiple threads and external processes concurrently output to the
    console, without it getting all garbled up.
    .
    Built on top of that is a way of defining multiple output regions,
    which are automatically laid out on the screen and can be individually
    updated by concurrent threads. Can be used for progress displays etc.
    .
    <<https://joeyh.name/code/concurrent-output/demo2.gif>>
category: User Interfaces
author: Joey Hess, Joachim Breitner
exposed: True
exposed-modules:
    System.Console.Concurrent System.Console.Concurrent.Internal
    System.Console.Regions System.Process.Concurrent
hidden-modules: Utility.Monad Utility.Data Utility.Exception
abi: 342f4854e622f1256e69fe5fd225b2c0
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/concurrent-output-1.7.9
library-dirs: /usr/lib/ghc-8.0.1/site-local/concurrent-output-1.7.9
data-dir: /usr/share/i386-linux-ghc-8.0.1/concurrent-output-1.7.9
hs-libraries: HSconcurrent-output-1.7.9-GNR3nVD7tnXCDV8G96TgZE
depends:
    ansi-terminal-0.6.2.3-AKTYR0nthhUCHW4HMZvJFX
    async-2.1.1.1-H3AbYkdNxWLAjCWaC7fyS4 base-4.9.0.0 directory-1.2.6.2
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN process-1.4.2.0
    stm-2.4.4.1-9HlGYelGmT69YkepeDjuRg
    terminal-size-0.3.2.1-LpkVHWZKZXdLX20uKh4q0i
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v transformers-0.5.2.0
    unix-2.7.2.0
haddock-interfaces: /usr/share/doc/haskell-concurrent-output/html/concurrent-output.haddock
haddock-html: /usr/share/doc/haskell-concurrent-output/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
